# -*- coding: UTF-8 -*-
class Property:
    properties = {}

    def __init__(self, arg):
        if isinstance(arg, str):
            self.get_from_file(arg)
        else:
            self.get_from_json(arg)

    def get_from_json(self, json_val):
        self.properties = dict(json_val)

    def get_from_file(self, file_path):
        try:
            config = open(file_path, 'r')
            for line in config:
                if line.find('=') > 0:
                    strs = line.replace('\n', '').split('=')
                    key, value = strs[0], strs[1]
                    self.properties[key] = value
                else:
                    raise Exception('config file format error')
        except Exception as e:
            print('配置文件读取出现问题')
            raise e
        else:
            config.close()

    def get_property(self, key):
        return self.properties[key]



# -*- coding: UTF-8 -*-
import enum
import requests
import time
import datetime
import random


class CheckType(enum.Enum):
    # 前面为方法名，后面为最大等待时间(单位：min)
    CHECK_IN = 'checkin', 11
    CHECK_OUT = 'checkout', 50
    LOGIN_CHECK = '', 0.5


def wait(check_type, delay, delay_min=0):
    if check_type == CheckType.CHECK_OUT:
        delay_min = delay_min
    else:
        delay_min = check_type.value[1]
    # 最少要延迟20s
    t = random.randint(20, delay_min * 60)
    print('\n\twill be waiting for ' + str(t) + ' seconds!\n')
    if check_type == CheckType.LOGIN_CHECK or delay:
        print('\n\twill be waiting for ' + str(t) + ' seconds!\n')
        time.sleep(t)
    else:
        print('don\'t sleep')


class AutoChecker:
    __check_headers = {
        'User-Agent': 'E-MobileE-Mobile 6.5.64 (iPhone; iOS 12.1; zh_CN)',
        'Accept-Encoding': 'gzip',
        'Connection': 'keep-alive',
    }

    def __init__(self, config, test, delay):
        self.__udid = config.get_property('udid')
        self.__username = config.get_property('username')
        self.__password = config.get_property('password')
        self.__latlng = config.get_property('latlng')
        self.__addr = config.get_property('addr')
        self.__server = config.get_property('server')
        self.__test = test
        self.__delay = delay
        self.__off_delay = config.get_property('check_delay')

    def __get_cio_cookie(self, user_key='', session_id='', user_id='1'):
        return dict([('ClientCountry', 'CN'), ('ClientLanguage', 'zh-Hans'), ('ClientMobile', ''), ('ClientToken', ''),
                     ('ClientType', 'iPhone'), ('ClientUDID', self.__udid), ('ClientVer', '6.5.64'),
                     ('JSESSIONID', session_id),
                     ('Pad', 'false'), ('setClientOS', 'iOS'), ('setClientOSVer', '12.1'), ('userKey', user_key),
                     ('userid', user_id)])

    def __check_inout(self, check_type):
        url = 'http://' + self.__server + '/client.do?method=checkin&type=' + check_type.value[0] + '&latlng=' + self.__latlng + '&addr=' + self.__addr + '&sessionkey=abcTX_cZ9RjYt5MD_CjBw&wifiMac='

        # 先等待，营造随机效果
        # 如果需要延时
        wait(check_type, self.__delay, self.__off_delay)
        # 登录获取cookie
        args = self.__login()
        # 登录后等待一段时间
        wait(CheckType.LOGIN_CHECK, self.__delay)

        if not self.__test:
            r = requests.get(url, headers=self.__check_headers, cookies=self.__get_cio_cookie(args['user_key'], args['session_id'], args['user_id']))
            print(self.__username + ' -- ' + str(r.status_code) + ' ---> ' + r.text)
        else:
            print(self.__username + ' *** ' + url)



    # 登录获取最新cookie
    def __login(self):
        headers = {
            'Host': self.__server,
            'Content-Type': 'application/x-www-form-urlencoded; charset=utf-8',
            'Proxy-Connection': 'close',
            'Timezone': 'GMT+8',
            'User-Agent': 'E-MobileE-Mobile 6.5.64 (iPhone; iOS 12.1; zh_CN)',
            'Content-Length': '25',
            'Accept-Encoding': 'gzip',
            'Connection': 'close'
        }
        url = 'http://' + self.__server + '/client.do?method=login&udid=' + self.__udid + '&token=&language=zh-Hans&country=CN&isneedmoulds=1&clienttype=iPhone&clientver=6.5.64&clientos=iOS&clientosver=12.1&authcode=&dynapass=&tokenpass=&clientChannelId=&clientuserid=&relogin=';
        data = {
            'loginid': self.__username,
            'password': self.__password
        }
        r = requests.post(url, data=data, headers=headers, cookies=self.__get_cio_cookie(), timeout=2)
        try:
            cookies = dict([('user_key', r.cookies['userKey']), ('session_id', r.cookies['JSESSIONID']),
                     ('user_id', r.cookies['userid'])])
            print(self.__username + ' -- ' + str(cookies))
            return cookies
        except Exception as e:
            print(self.__username + ' -- 登录失败 --' + r.text)
            raise e

    # 延时等待
    def check(self):
        # 获取当前时间
        current_time = int((datetime.datetime.utcnow() + datetime.timedelta(hours=8)).strftime('%H'))
        # 根据时间进行判断进行签到、签退
        if 8 <= current_time <= 9:
            print('签到({}):'.format(self.__username))
            self.__check_inout(CheckType.CHECK_IN)
        elif 18 <= current_time <= 20:
            print('签退({}):'.format(self.__username))
            self.__check_inout(CheckType.CHECK_OUT)
        elif self.__test:
            print('\n--\tTest({}):\t--\n'.format(self.__username))
            self.__check_inout(CheckType.CHECK_IN)
            self.__check_inout(CheckType.CHECK_OUT)
        else:   
            print('\n\t{}--不在正常时间内，不建议进行签到/退操作。\n'.format(self.__username))
            



# -*- coding: UTF-8 -*-
import json
import threading
import os
import time

import requests

from .checker.auto_checker import AutoChecker
from .bean.property import Property
from .common.parse_params import parse


def is_holiday():
    try:
        url = 'http://api.goseek.cn/Tools/holiday?date=' + time.strftime('%Y%m%d', time.localtime())
        resp = requests.get(url).json()
        print(resp)
    except Exception:
        # 请求接口失败，调用本地日历，进行基本判断
        print('查询API失败，调用本地日历，判断是否为周末')
        return 5 <= time.localtime()[6] <= 6
    else:
        return resp['data'] == 1 or resp['data'] == 3


def get_check_conf(url):
    try:
        conf = requests.get(url).json()
    except Exception:
        print('获取配置信息失败')
        return json
    else:
        return conf


def main(**kwargs):
    # 解析参数
    params = parse()
    if params.url == '' and params.config_dir == '':
        print('No conf info defined, please check again or use -h')
        return
    # 工作日判定
    if is_holiday():
        print('holiday')
        return
    print('workday')
    # 优先从网络获取配置参数
    if params.url != '':
        resp = str(requests.get(params.url).content).replace('b\'', '').replace(']\'', ']')
        # print(resp)
        configs = json.loads(resp)
        print(configs)
        for conf in configs:
            print(conf['username'])
            # 若已设置过滤，
            if params.suffix != '':
                if not conf['username'].__contains__(params.suffix):
                    pass
                else:
                    t = threading.Thread(target=AutoChecker(Property(conf), params.test, not params.immediately).check,
                                         name=conf['username'])
                    t.start()
                    break
            else:
                t = threading.Thread(target=AutoChecker(Property(conf), params.test, not params.immediately).check,
                                     name=conf['username'])
                t.start()
    # 再从本地获取
    elif params.config_dir != '':
        print('local config not supported any more')
        return
        configs = os.listdir(params.config_dir)
        os.chdir(params.config_dir)

        cnt = 0
        for config_name in configs:
            if config_name.__contains__('config_' + params.suffix):
                print(config_name)
                t = threading.Thread(
                    target=AutoChecker(Property(config_name), params.test, not (params.immediately)).check,
                    name=config_name)
                t.start()
                cnt += 1
        print('There are ' + str(cnt) + ' configuration file(s) satisfied. ')
    else:
        print('No conf info defined, please check again or use -h')
        return


if __name__ == '__main__':
    main()



#!/usr/local/bin/python3
# -*- coding: UTF-8 -*-
import argparse
import sys

class params:
    pass

def parse():
    p = params()
    parser = argparse.ArgumentParser('auto_check', description='A script for checking in & out automatically, which is just for fun ^_^.',)

    # parser = argparse.ArgumentParser(
    #     prog='自动打卡签到',
    #     #usage='python3 __main__.py [OPTION]... URL...',
    #
    #     add_help=False,
    # )

    parser.add_argument(
        '-v', '--version', action='store_true',
        help='print version and exit'
    )

    run_grp = parser.add_argument_group(
        'Run options'
    )
    run_grp.add_argument(
        '-c', '--config_dir', action='store', default='',
        help='the config files\' directory path'
    )
    run_grp.add_argument(
        '-u', '--url', action='store', default='',
        help='the url which used to get conf'
    )
    run_grp.add_argument(
        '-s', '--suffix', action='store', default='',
        help='run the config ending with the specific suffix'
    )
    run_grp.add_argument(
        '-t', '--test', action='store_true',
        help='set to test mode, aka not perform checking in or out'
    )
    run_grp.add_argument(
        '-i', '--immediately', action='store_true',
        help='perform checking in or out with random delay'
    )
    args = parser.parse_args(sys.argv[1:], namespace=p)

    if args.version:
        print('Auto Checker v0.1.3')
        sys.exit()

    return p



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
setup(
    name='auto-check',
    # version='0.1.3',
    version='0.1.3',
    description='主要用于针对使用E-Mobile自动打卡',
    long_description=open('README.rst').read(),
    author='一条肥鱼',
    author_email='sasuraiu@gmail.com',
    maintainer='一条肥鱼',
    maintainer_email='sasuraiu@gmail.com',
    license='MIT License',
    packages = find_packages('src'),
    platforms=["all"],
    url='https://github.com/sasuraiu/autocheck',
    package_dir={'':'src'},
    classifires = [
        'Programming Language :: Python :: 3',
    ],
    install_requires=[
        'requests',
    ],
    entry_points = {
        'console_scripts':[
            'auto-check = auto_check.__main__:main'
        ]
    },
)